@@ -1,5 +1,7 @@
 library(utils)	
 
 input <- readLines ("in.txt")	
+print ("foo")
+print (input)
 
 source ("script2.r")
\ No newline at end of file
